@@ -17,18 +17,18 @@ extensions = [
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'Hunter'
-year = '2015-2024'
+year = '2015-2025'
 author = 'Ionel Cristian Mărieș'
 copyright = f'{year}, {author}'
 try:
-    from pkg_resources import get_distribution
+    from importlib import metadata
 
-    version = release = get_distribution('hunter').version
+    version = release = metadata.version('hunter')
 except Exception:
     import traceback
 
     traceback.print_exc()
-    version = release = '3.7.0'
+    version = release = '3.8.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -50,7 +50,3 @@ html_short_title = f'{project}-{version}'
 napoleon_use_ivar = True
 napoleon_use_rtype = False
 napoleon_use_param = False
-
-autosummary_generate = True
-
-autosectionlabel_prefix_document = True
